
Módulo ``satcfe.resposta.consultarstatusoperacional``
=====================================================

.. automodule:: satcfe.resposta.consultarstatusoperacional
    :members:
    :undoc-members:
